#
# spec file for package libnma
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%define base_ver 1.10

Name:           libnma
Version:        1.10.6
Release:        3.3
Summary:        Shared library for NetworkManager-applet
License:        GPL-2.0-or-later
URL:            https://gitlab.gnome.org/GNOME/libnma
Source0:        https://download.gnome.org/sources/%{name}/%{base_ver}/%{name}-%{version}.tar.xz

BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gck-2)
BuildRequires:  pkgconfig(gcr-4)
BuildRequires:  pkgconfig(gio-2.0) >= 2.38
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.6
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12
BuildRequires:  pkgconfig(gtk4) >= 4.0
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libnm) >= 1.7
BuildRequires:  pkgconfig(mobile-broadband-provider-info)
BuildRequires:  pkgconfig(vapigen)

%description
Shared library for NetworkManager-applet.

%package -n     %{name}%{sover}
Summary:        Shared library for NetworkManager-applet
# Make lang package installable.
Provides:       %{name}
# Since version 1.8.28
Obsoletes:      nma-data < %{version}
Provides:       nma-data = %{version}
Obsoletes:      libnma-data < %{version}
Provides:       libnma-data = %{version}
Requires:       %{name}-glib-schema >= %{version}
Requires:       mobile-broadband-provider-info

%description -n %{name}%{sover}
Shared library for NetworkManager-applet.

%package glib-schema
Summary:        GLib-schema org.gnome.nm-applet.eap
BuildArch:      noarch

%description glib-schema
The glib-schema allows libnma to be configured wia dconf

It is required by libnma

%package -n     %{name}-gtk4-%{sover}
Summary:        Shared library for NetworkManager-applet. Gtk4 version
Requires:       %{name}-glib-schema >= %{version}
Requires:       mobile-broadband-provider-info

%description -n %{name}-gtk4-%{sover}
Shared library for NetworkManager-applet. Gtk4 version.

%package -n     typelib-1_0-NMA-1_0
Summary:        Introspection bindings for %{name}

%description -n typelib-1_0-NMA-1_0
Introspection bindings for %{name}.

%package -n     typelib-1_0-NMA4-1_0
Summary:        Introspection bindings for %{name}

%description -n typelib-1_0-NMA4-1_0
Introspection bindings for %{name}.

%package        devel
Summary:        Development Files for %{name}
Requires:       %{name}%{sover} = %{version}
Requires:       typelib-1_0-NMA-1_0 = %{version}

%description    devel
Development Files for %{name}.

%package        gtk4-devel
Summary:        Development Files for %{name}-gtk4
# Depend on main devel package for the shared header files.
Requires:       %{name}-devel = %{version}
Requires:       %{name}-gtk4-%{sover} = %{version}
Requires:       typelib-1_0-NMA4-1_0 = %{version}

%description    gtk4-devel
Development Files for %{name}-gtk4.

%package        docs
Summary:        Documentation files for %{name}
BuildArch:      noarch

%description    docs
Documentation files for %{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D b_lto=true \
	-D libnma_gtk4=true \
	-D gcr=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
# this file lives in NetworkManager-applet since 1.30.0
rm %{buildroot}%{_datadir}/glib-2.0/schemas/org.gnome.nm-applet.gschema.xml

%ldconfig_scriptlets -n %{name}%{sover}
%ldconfig_scriptlets -n %{name}-gtk4-%{sover}

%files -n %{name}%{sover}
%license COPYING
%doc NEWS
%{_libdir}/%{name}.so.*

%files glib-schema
%{_datadir}/glib-2.0/schemas/org.gnome.nm-applet.eap.gschema.xml

%files -n %{name}-gtk4-%{sover}
%{_libdir}/%{name}-gtk4.so.*

%files -n typelib-1_0-NMA-1_0
%{_libdir}/girepository-1.0/NMA-1.0.typelib

%files -n typelib-1_0-NMA4-1_0
%{_libdir}/girepository-1.0/NMA4-1.0.typelib

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/gir-1.0/NMA-1.0.gir
%{_datadir}/vala/vapi/%{name}.deps
%{_datadir}/vala/vapi/%{name}.vapi

%files gtk4-devel
%{_libdir}/%{name}-gtk4.so
%{_libdir}/pkgconfig/%{name}-gtk4.pc
%{_datadir}/gir-1.0/NMA4-1.0.gir
%{_datadir}/vala/vapi/%{name}-gtk4.deps
%{_datadir}/vala/vapi/%{name}-gtk4.vapi

%files docs
%doc %{_datadir}/gtk-doc/html/%{name}/

%files lang -f %{name}.lang

%changelog
* Tue Oct 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(gck-1) and pkgconfig(gcr-3) BuildRequires: No
  longer needed, we build with gck-2 and gcr-4.
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add libnma-glib-schema Requires to libnma-gtk4-0 sub-package,
  ensure libnma-glib-schema gets installed by default now that
  gnome-control-center have ported to gtk4.
* Tue Jan 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.10.6:
  + Fix the path and translation domains of GSchema files.
  + Removed strings that don't match our conscious language
    standards from the translation files.
  + Added autoptr support.
  + Fix translations of country and territory names in the mobile
    broadband dialog.
  + Honor explicitly set APN if provider was not present in the
    mobile broadband dialog.
  + Make sure Kosovar operators are ordered properly in the mobile
    broadband dialog.
- Drop libnma-schema-without-path.patch: Fixed upstream.
- Package libnma-glib-schema sub-package as noarch.
* Mon Nov 14 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add libnma-schema-without-path.patch: Do not specify path in
  nm-applet.eap schema (glgo#GNOME/libnma!18, boo#1205362).
* Tue Nov  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.10.4:
  + Split org.gnome.nm-applet.eap GSchema from org.gnome.nm-applet,
    so that the latter can be provided by network-manager-applet
    again (where it belongs).
  + build: unbreak build with gcr-3.92.
- split out schema file from the library package: adhere to the
  shared library policy. The library requires the new
  libnma-glib-schema package.
- Drop fix-dependency-pc-name.patch: fixed upstream.
* Fri Sep  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.10.2:
  + Do not pop a certificate chooser if nobody clicked the button.
  + Updated translations.
* Wed Sep  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.10.0:
  + Libnma-gtk4 now has Smart Card support viad Gtk4-enabled
    version of Gcr.
  + nma-cert-chooser.c is now included in the list of translated
    files.
- Add fix-dependency-pc-name.patch: Update gcr-4.pc name to new
  form. Following this: Add pkgconfig(gcr-4) and pkgconfig(gck-2)
  BuildRequires and pass gcr_gtk4=true to meson, build the new
  gcr-gtk4 based advanced certificate chooser.
- Pass b_lto=true to meson, build with LTO support.
* Thu Jun 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.40:
  + Ad-Hoc networks now default to using WPA2 instead of WEP.
  + WEP is no longer provided as an option for connecting to hidden
    networks due to its deprecated status.
- Package docs sub-package as noarch.
* Thu Apr  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.38:
  + libnma-gtk4 is no longer considered EXPERIMENTAL.
  + meson now builds libnma-gtk4 properly.
  + Keyboard accelerator for certificate chooser works again.
  + Fixed libnma-gtk4 version of mobile-wizard.
* Fri Mar 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.36:
  + Include OWE wireless security option.
  + Do not allow setting empty 802.1x domain for EAP TLS.
  + The GtkBuilder files for Gtk4 are now included in the release
    tarball.
* Wed Jan 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.34:
  + Add possibility of building libnma-gtk4 library with
    experimental Gtk4 support.
- Add pkgconfig(gtk4) BuildRequires and pass libnma_gtk4=true to
  meson, build the experimental Gtk4 support.
- Following the above, package new sub-packages libnma-gtk4-0 and
  typelib-1_0-NMA4-1_0 and libnma-gtk4-devel.
- Use ldconfig_scriptlets for post(un) handling.
- Split out documentation files in own docs sub-package.
* Fri Aug 20 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.32:
  + Fix crash in PKCS11 login dialog.
  + Fix clearing password when restoring a valid configuration to
    be displayed to a user.
* Tue Jun 23 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.30:
  + Properly dispose wireless security objects.
  + Don't clear the key when users set a non-pkcs12 certificate in
    the certificate chooser UI.
  + Added missing VAPI macro file.
- Drop libnma-fix-segment-fault.patch: Fixed upstream.
* Thu Jun  4 2020 Jonathan Kang <songchuan.kang@suse.com>
- Make libnma require mobile-broadband-provider-info(bsc#1172499).
* Fri Apr 17 2020 Jonathan Kang <songchuan.kang@suse.com>
- Add libnma-fix-segment-fault.patch: nma-ws: properly dispose
  wireless security objects(bsc#1168347 glgo#GNOME/libnma#7).
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.28:
  + Turned the wireless-security library to a public API.
  + "org.gnome.nm-applet.gschema.xml" is now part of libnma.
    Previously, on distributions like Fedora it was packaged as
    part of nm-connection-editor package. But the schema is used by
    wireless-security library, gnome-control-center and
    nm-a/nm-c-e.
  + Clear key/password input fields when selecting a different
    certificate in NMACertChooser.
  + Generate vapi files.
- Add pkgconfig(vapigen) BuildRequires: New dependency.
- Drop nma-data Requires: No longer needed. Add nma-data and
  libnma-data Provides and Obsoletes, make upgrades problemfree
  for our end-users.
* Mon Dec  9 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Require nma-data by libnma0: the library references the
  org.gnome.nm-applet schema, which is packaged in nma-data
  (boo#1157889).
* Mon Oct 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add virtual libnma Provides in the main lib package, make the
  lang package installable.
* Fri Oct 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Inital packaging for openSUSE, version 1.8.26.
